@@ -2,20 +2,20 @@ context("basic model creation of staged event trees")
 
 test_that("test that the creator works for list", {
   ev <-
-    staged_ev_tree(x = list(
+    sevt(x = list(
       A = c(1, 2),
       B = c("x", "y"),
       C = c("3", "4")
     ))
   expect_is(ev, "sevt")
   ev <-
-    staged_ev_tree(x = list(
+    sevt(x = list(
       c(1, 2),
       c("x", "y"),
       c("3", "4")
     ))
   expect_is(ev, "sevt")
-  expect_error(staged_ev_tree(x = list(
+  expect_error(sevt(x = list(
     NULL,
     c("x", "y"),
     c("3", "4")
@@ -25,7 +25,7 @@ test_that("test that the creator works for list", {
 test_that("test that the creator works for data.frame", {
   DD <-
     data.frame(A = as.factor(c(1, 2, 2, 1)), B = as.factor(c("a", "b", "a", "b")))
-  ev <- staged_ev_tree(x = DD, order = c("B", "A"))
+  ev <- sevt(x = DD, order = c("B", "A"))
   expect_is(ev, "sevt")
 })
 
@@ -33,13 +33,13 @@ test_that("test that the creator works for tables", {
   DD <-
     data.frame(A = as.factor(c(1, 2, 2, 1)), B = as.factor(c("a", "b", "a", "b")))
   DD <- table(DD)
-  ev <- staged_ev_tree(x = DD, order = c("B", "A"))
+  ev <- sevt(x = DD, order = c("B", "A"))
   expect_is(ev, "sevt")
 })
 
 test_that("test that the staged event tree is created with the right order I", {
   ev <-
-    staged_ev_tree(x = list(
+    sevt(x = list(
       A = c(1, 2),
       B = c("x", "y"),
       C = c("3", "4")
@@ -50,7 +50,7 @@ test_that("test that the staged event tree is created with the right order I", {
 test_that("test that the staged event tree is created with the right order II", {
   DD <-
     data.frame(A = as.factor(c(1, 2, 2, 1)), B = as.factor(c("a", "b", "a", "b")))
-  ev <- staged_ev_tree(x = DD, order = c("B", "A"))
+  ev <- sevt(x = DD, order = c("B", "A"))
   expect_true(all(names(ev$tree) == c("B", "A")))
 })
 
@@ -64,7 +64,7 @@ test_that("test that the staged event tree is fitted", {
       C = as.factor(c("SD", "de", "rew", "tyu")),
       D = as.factor(c("a", "uu", "a", "uu"))
     )
-  ev <- staged_ev_tree(x = DD, fit = TRUE, lambda = 0)
+  ev <- stagedtrees:::sevt_fit(sevt(x = DD), data = DD, lambda = 0)
   for (var in c("A", "B", "C", "D")) {
     expect_equal(as.numeric(ev$prob[[var]][[1]]), as.numeric(table(DD[var]) / sum(table(DD[var]))))
   }
@@ -79,7 +79,7 @@ test_that("test that probabilities are probabilities (indep model)", {
       replace = TRUE
     )))
   }))
-  sev <- staged_ev_tree(DD, fit = T, lambda = 1)
+  sev <- stagedtrees:::sevt_fit(sevt(DD), data = DD, lambda = 1 )
   for (i in 1:4) {
     for (j in 1:3) {
       expect_gte(sev$prob[[i]][[1]][j], 0) ## test prob are >=0
@@ -104,11 +104,8 @@ test_that("test that probabilities are probabilities (full model)", {
       replace = TRUE
     )))
   }))
-  sev <- staged_ev_tree(DD,
-    full = TRUE,
-    fit = T,
-    lambda = 1
-  )
+  sev <- stagedtrees:::sevt_fit(sevt(DD, full = TRUE), data = DD, 
+                  lambda = 1)
   for (i in 1:4) {
     for (s in 1:length(sev$prob[[i]])) {
       for (j in 1:3) {
@@ -136,9 +133,9 @@ test_that("test indep model", {
       replace = TRUE
     )))
   }))
-  sev1 <- staged_ev_tree(DD, lambda = 1)
+  sev1 <- stagedtrees:::sevt_fit(sevt(DD), data = DD, lambda = 1)
 
-  sev2 <- indep(DD, lambda = 1)
+  sev2 <- indep(DD, lambda = 1, join_unobserved = FALSE)
 
-  expect_true(compare.sevt(sev1, sev2))
+  expect_true(compare_stages(sev1, sev2))
 })
